translate.convert.accesskey

Package translate :: Package convert :: Module accesskey |
[hide private]
[frames] | no frames]

# Module accesskey

source code

functions used to manipulate access keys in strings

Functions | [hide private]
extract(string, accesskey_marker=`u'``&``'`) Extract the label and accesskey from a label+accesskey string | source code
unicode or None |
combine(label, accesskey, accesskey_marker=`u'``&``'`) Combine a label and and accesskey to form a label+accesskey string | source code

Variables | [hide private]
| DEFAULT_ACCESSKEY_MARKER = ``u'``&``'``
| __package__ = ``'``translate.convert``'``

Imports: XMLEntityPlaceable

Function Details | [hide private]

### extract(string, accesskey_marker=`u'``&``'`) | source code
Extract the label and accesskey from a label+accesskey string The function will also try to ignore &entities; which would obviously not contain accesskeys. Parameters: `string` (Unicode) - A string that might contain a label with accesskey marker `accesskey_marker` (Char) - The character that is used to prefix an access key

### combine(label, accesskey, accesskey_marker=`u'``&``'`) | source code
Combine a label and and accesskey to form a label+accesskey string We place an accesskey marker before the accesskey in the label and this creates a string with the two combined e.g. "File" + "F" = "&File" Parameters: `label` (unicode) - a label `accesskey` (unicode char) - The accesskey Returns: unicode or None label+accesskey string or None if uncombineable